@@ -15,7 +15,7 @@ from decimal import Decimal
 from io import BytesIO
 from ssl import CERT_NONE, CERT_OPTIONAL, CERT_REQUIRED
 
-from e6xdb.server import QueryEngineService
+from e6data_python_connector.server import QueryEngineService
 from thrift.protocol import TBinaryProtocol, TMultiplexedProtocol
 from thrift.transport import TSocket
 from thrift.transport import TTransport
@@ -120,9 +120,6 @@ class Connection(object):
         # service_name = 'E6x'  # E6x  QueryExecutor
         service_name = 'QueryEngine'  # E6x  QueryExecutor
 
-        if scheme != "e6data":
-            raise ValueError("scheme is not e6data")
-
         if not self.__username or not self.__password:
             raise ValueError("username or password cannot be empty.")
         if port is None:
